@@ -8,7 +8,7 @@ except ImportError:
 else:
     class AttrField(RecordField[attr.Attribute]):
         def is_required(self) -> bool:
-            return self.field.default is attr.NOTHING
+            return self._field.default is attr.NOTHING
 
 
     class AttrClass(RecordClass[attr.Attribute]):
